EventAst class abstract

Represents an event listener (eventName.reductions)="expression" on an element.

Clients should not extend, implement, or mix-in this class.

Implemented types
Implementers

Constructors

EventAst(String name, String? value, [List<String> reductions])
Create a new synthetic EventAst listening to name.
factory
EventAst.from(TemplateAst origin, String name, String? value, [List<String> reductions])
Create a new synthetic EventAst that originated from origin.
factory
EventAst.parsed(SourceFile sourceFile, NgToken prefixToken, NgToken elementDecoratorToken, NgToken? suffixToken, [NgAttributeValueToken? valueToken, NgToken? equalSignToken])
Create a new EventAst parsed from tokens in sourceFile.
factory

Properties

beginToken → NgToken?
First token that was used to form this AST.
finalinherited
childNodes → List<StandaloneTemplateAst>
Child nodes, if any.
no setterinherited
endToken → NgToken?
Last token that was used to form this AST.
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
isParent → bool
Whether this node is capable of containing children and does.
finalinherited
isStandalone → bool
Whether this node needs to be 'attached' to another node to be valid.
no setterinherited
isSynthetic → bool
Whether this node did not truly originate from the parsed source.
finalinherited
name → String
Name of the event being listened to.
no setter
reductions → List<String>
An optional list of postfixes used to filter events that support it.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceSpan → SourceSpan
Segment of source text from which the AST was parsed from.
no setterinherited
sourceUrl → String?
no setterinherited
value → String?
Unquoted value being bound to event.
no setter

Methods

accept<R, C>(TemplateAstVisitor<R, C?> visitor, [C? context]) → R
Have the visitor start visiting this node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object? other) → bool
The equality operator.
override