NgAttributeValueToken class

Inheritance

Constructors

NgAttributeValueToken.generate(NgToken leftQuote, NgToken? innerValue, NgToken rightQuote)
factory

Properties

containsErrorSynthetic → bool
no setter
end → int
Indexed location where the token ends in the original source text.
no setteroverride
errorSynthetic → bool
Indicates synthetic token generated from error.
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
innerValue → NgToken?
final
isDoubleQuote → bool
no setter
isSingleQuote → bool
no setter
leftQuote → NgToken?
final
length → int
Number of characters in this token.
no setteroverride
lexeme → String
What characters were scanned and represent this token.
no setteroverride
offset → int
Indexed location where the token begins in the original source text.
finalinherited
rightQuote → NgToken?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → NgTokenType
Type of token scanned.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object? other) → bool
The equality operator.
override