NgParser class

Constructors

NgParser()
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String template, {required String sourceUrl, bool desugar = true, ExceptionHandler exceptionHandler = const ThrowingExceptionHandler()}) → List<StandaloneTemplateAst>
Return a series of tokens by incrementally scanning template.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited