ParsedEmbeddedContentAst class

Inheritance
Mixed-in types

Constructors

ParsedEmbeddedContentAst(SourceFile sourceFile, NgToken startElementToken, NgToken identifierToken, NgToken endElementToken, CloseElementAst closeComplement, [AttributeAst? selectAttribute, AttributeAst? ngProjectAsAttribute, ReferenceAst? reference])

Properties

beginToken → NgToken?
First token that was used to form this AST.
finalinherited
childNodes → List<StandaloneTemplateAst>
Child nodes, if any.
no setterinherited
closeComplement ↔ CloseElementAst
that is paired to this
getter/setter pairoverride
endToken → NgToken?
Last token that was used to form this AST.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
identifierToken → NgToken
final
isParent → bool
Whether this node is capable of containing children and does.
finalinherited
isStandalone → bool
Whether this node needs to be 'attached' to another node to be valid.
no setterinherited
isSynthetic → bool
Whether this node did not truly originate from the parsed source.
finalinherited
ngProjectAs → String?
A CSS selector denoting what this embedded content should be projected as.
no setteroverride
ngProjectAsAttribute → AttributeAst?
final
reference → ReferenceAst?
Reference assignment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectAttribute → AttributeAst?
final
selector → String?
A CSS selector denoting what elements should be embedded.
no setteroverride
sourceSpan → SourceSpan
Segment of source text from which the AST was parsed from.
no setterinherited
sourceUrl → String?
no setterinherited

Methods

accept<R, C>(TemplateAstVisitor<R, C?> visitor, [C? context]) → R
Have the visitor start visiting this node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object? other) → bool
The equality operator.
inherited